''' Reads quote information from a config file and fetches + prints quote 
information for each quote. '''

import getopt, sys

from Config import *
from core import QdlCore 
from core.Model import *
from kmm.KmmQuoteService import KmmQuoteService
from pfq.PfqQuoteService import PfqQuoteService


def  displayHelp():
      print "QDL-Batch"
      print "Usage: QDL-Batch.py [Options] configfile"
      print "Infile: driver,source,symbol,name"
      print "Options:"
      print "  -D: Enable debug"
      print "  -h: This help screen"
      print "  -T: Enable trace (heavy debug)"
    

def parseInput(filename):
      quoteInputs = []
      f = open(filename)
      lines = f.readlines()

      for line in lines:
            # skip comment lines
            if line.startswith("#"):
                  continue
            
            # for each config line get settings and remove line breaks
            line = line.replace("\n","")
            line = line.replace("\r","")
            itemlist = line.split(",")
      
            #skip empty lines
            if line == "":
                  continue

            # create the QuoteInput model
            qi = QuoteInput()
            qi.driver=itemlist[0]
            qi.source = itemlist[1]
            qi.symbol=itemlist[2]
            if len(itemlist) > 3:
                  qi.name =",".join(itemlist[3:])
            quoteInputs.append(qi)    

      return quoteInputs

def getQuotes(inputs,  debug = 0,  debugAll = 0):
      errors = []
      quotes = []
      for input in inputs:
            input.debug = debug
            input.debugAll = debugAll
            try:
                  res = QdlCore.getQuote(input)
                  quotes.append(res)
            except Exception,  inst:
                  errors.append("Error retrieving quote " + input.symbol)
      return quotes,  errors
    
def main(args):
      # no argument > show help + exit
      optlist, args = getopt.getopt(sys.argv[1:], 'hDT')

      if  len(args) < 1:
            displayHelp()
            sys.exit()
            
      debug = 0
      debugAll = 0
      for o,  a in optlist:
            if o == "-h":
                  displayHelp()
            if o == "-T" :
                  debugAll = 1
            if o == "-D":
                  debug = 1
           
        
      infile = args[0]
      inputs = parseInput(infile)
      quotes,  errors = getQuotes(inputs,  debug,  debugAll)
      for quote in quotes:
            print quote.toString()
      if (len(errors) > 0):
            errorStr = "\n" + "\n".join(errors)
            e = StandardError(errorStr)
            raise e

        
if __name__=="__main__":
      main(sys.argv)
        
        
