''' Client mode. Fetches a single quote based on the command 
line options and prints the result to the sys.out.'''
import getopt, sys

import Config
from Config import *
from core import QdlCore 
from core.Model import *
from kmm.KmmQuoteService import KmmQuoteService
from pfq.PfqQuoteService import PfqQuoteService


def  displayHelp():
      print "QDL-Client"
      print "Usage: QDL-Client.py [Options] symbol"
      print "Options:"
      print "  -d: The driver to use. Either kmm (default, KMyMoney) or pfq (Perl Finance::Quote). Optional"
      print "  -D: Enable debug"
      print "  -h: Shows this help screen"
      print "  -l: List all available sources"
      print "  -s: The source to use."
      print "  -T: Enable trace (heavy debug)"
      print "  -n: Use the name provided (e .g the WKN) in addition to the symbol"
      print "      given. Optional"

def parseArgs(options):
    optlist, args = getopt.getopt(sys.argv[1:], 'd:Dhln:s:Tw:')
    
    # no options, no arguments > show help
    if len(optlist) == 0 and len(args) == 0:
        displayHelp()
        sys.exit()

    # parse arguments 
    for o, a in optlist:
            if o == "-l":
                  print QdlCore.getAllSources()
                  sys.exit()
            if o == "-h":
                  displayHelp()
                  sys.exit()
            if o == "-d":
                  if a not in drivers:
                        sys.stderr.write("Error! Invalid driver. Use one of: " + ", ".join(drivers))
                        sys.exit()
                  options.driver = a
            if o == "-D":
                  options.debug = 1
            if o == "-s":
                  options.source = a
            if o == "-T":
                  options.debugAll = 1
            if o == "-n":
                  options.name = a
            
    # no argument > show help + exit
    if  len(args) < 1:
        displayHelp()
        sys.exit()
            
    # validate source name for driver
    keysKmm  = QdlCore.getSourceNames("kmm")
    keysPfq = QdlCore.getSourceNames("pfq")
    keys = keysPfq + keysKmm
    if options.driver == "kmm" and options.source not in keysKmm:
        sys.stderr.write("Error! Invalid source name for driver 'kmm'. Avaliable sources as follows\n")
        print QdlCore.getAllSources()
        sys.exit()
    if options.driver == "pfq" and options.source not in keysPfq:
        sys.stderr.write("Error! Invalid source name for driver 'pfq'. Avaliable sources as follows\n")
        print QdlCore.getAllSources()
        sys.exit()
            
    options.symbol = args[0]
    return options

def main(args):
    input = QuoteInput()
    input = parseArgs(input)
    quoteItem = QdlCore.getQuote(input)
    QdlCore.printQuote(quoteItem)
        
if __name__=="__main__":
    main(sys.argv)
        
        
