''' This module defines reusable methods for parsing
price, date etc. based on regexp definitions of a source
configuration. '''

import re
import re, urllib
from datetime import datetime, date
from time import strptime

def parseSymbol(sourceItem,  quoteStr,  debug=0):
      ''' Takes a source item object and the quite string to parse as argument.
      Returns the symbol or null( if no valid hits where found'''
                                 
      # no valid regexp for the symbol present
      if not sourceItem.symbol or len(sourceItem.symbol) == 0:
            return 
            
      symbolStr = re.split(sourceItem.symbol,  quoteStr,  1)
      symbolStr = symbolStr[1]

      if debug:
            print "Debug SymbolString: " + symbolStr
      return symbolStr

def parseDate(sourceItem, quoteStr,  debug=0):
      ''' Takes a SourceItem object and the quote string to parse as argument.
      Returns the date in the quote string as date object'''
      dateStr = re.split(sourceItem.date, quoteStr, 1)
      dateStr = dateStr[1]
      if debug:
            print "Debug DateString: " + dateStr
      time = strptime(dateStr, sourceItem.dateformat)
      datum = date(time.tm_year, time.tm_mon, time.tm_mday)
      if debug:
            print "Debug Datum: " + datum.strftime( "%Y/%m/%d")
      return datum
    
    
def parsePrice(sourceItem, quoteStr,  debug=0):
      ''' Takes a SourceItem object and the quote string to parse as argument.
      Returns the price in the quote string as float.'''
      # get only the price part of the string
      priceStr = re.split(sourceItem.price, quoteStr, 1)
      priceStr = priceStr[1]
      if debug:
            print "Debug Price: " + priceStr

      # Only valid for european style 4.123,89 > change to default style
      if "," in priceStr and "." in priceStr:
            priceStr = priceStr.replace(".","")

      # European quotes: first we do a simple replace 459,62 > 459.62
      priceStr = priceStr.replace(",",".")

      price = float(priceStr)
      return price
      
