''' Module providing the relevant functionality for the kmm driver '''

import re, urllib

from KmmSources import KmmSources
from core.Model import QuoteResult
from core import Parser


class KmmQuoteService:
      ''' Class providing relevant functionality for the kmm driver'''
       
      def getQuote(self, source, symbol,  debug=0,  debugAll=0):
            ''' Returns quote information from a given source for a given symbol 
            as a QuoteResult object '''
            sources = KmmSources()
            src = sources.getSourceItem(source)

            if not src:
                  print "Invalid source name %s" % source
                  return
            
            quoteStr = self._downloadQuote(src, symbol,  debug, debugAll)
            quoteItem = self._parseQuote(src, symbol, quoteStr,  debug,  debugAll)
            return quoteItem
            
      def _downloadQuote(self, sourceItem, symbol,  debug=0,  debugAll=0):
            ''' Downloads the quote for a symbol from a source. The source is 
            provided as SourceItem object, the symbol as string. Returns the 
            complete quote retrieved as string '''
            url = sourceItem.url

            if url.find("%2") != -1:   # if we have two symbols in the source url
                  # TODO: add special handling for two symbols here, see KMyMoney. Only useful for currencies
                  pass
            else: # just one symbol possible
                  # replace the placeholder with our actual symbol 
                  url = url.replace("%1", symbol)
            if debug:
                  print "Debug URL: " + url
        
            # get the quote
            urlHandler = urllib.urlopen(url)
            quoteStr = urlHandler.read()
            return quoteStr
        
      def _parseQuote(self, sourceItem, symbol, quoteString,  debug=0,  debugAll=0):
            ''' Parses the quotestring and returns q QuoteResult object
            with the information derived. Takes a SourceItem defining the source
            to use, the symbol as string and the complete quoteString as arguments.'''
            hasSymbol = None
            hasPrice = None
            hasDate = None

            # prepare the string
            quoteString = re.sub('<[^>]*>', '', quoteString)            # remove html tags
            quoteString = re.sub('&\\w+;',' ', quoteString);            # &...;'s
            quoteString = " ".join(quoteString.split())                        # Extra white space

            if debugAll:
                  print "Debug Page: " + quoteString

            # symbol present? -> process it
            if re.compile(sourceItem.symbol).search(quoteString):
                  hasSymbol = 1
                  srcSymbol = Parser.parseSymbol(sourceItem,  quoteString,  debug)
                  
                  if srcSymbol:
                        symbol =  srcSymbol
                  

            # price present? -> process it
            if re.compile(sourceItem.price).search(quoteString):
                  hasPrice = 1
                  price = Parser.parsePrice(sourceItem, quoteString,  debug)

            # date present? -> process it
            if re.compile(sourceItem.date).search(quoteString):
                  hasDate = 1
                  datum = Parser.parseDate(sourceItem, quoteString,  debug)

            if debug:
                  print "Debug: Symbol=" + str(hasSymbol) + " Date=" + str(hasDate) + " Price=" + str(hasPrice)

            quote = QuoteResult(symbol, price, datum)
            return quote


