# -*- coding: utf-8 -*-
# coding=utf-8
''' Sources avaliable for the kmm module are defined in this module '''

from core.Model import *

class KmmSources:
      ''' Container class for all sources of the driver kmm '''
      
      # TODO: bo: add low, high, volume
      
      def __init__(self):
            ''' Default constructor '''
            self.sources = {}        
            self._initSources()
        
      def _initSources(self):
            ''' Initializes the sources defined '''
            
            # vwd.de, 
            self.sources["vwd"] = SourceItem("VWD",
                  "http://fondscontainer.vwd.de/vwd/fonds_einzelkurs_detail.htm?u=0&tranche=%1",
                  "ISIN:.(\\w+)", # symbol regexp
                  "Datum.(\\d+,\\d\\d)", # price regexp
                  "Stand:.(\d+\D+\d+\D+\d+)", #  date regexp
                  "%d.%m.%Y" # date format
            ) 

            # Symbol anstatt WKN oder ISIN erforderlich. Symbol entspricht dem letzten
            # Teil der URL
            self.sources["finanztreff"] = SourceItem("finanztreff",
                  "http://www.finanztreff.de/kurse_einzelkurs_detail,i,%1.html",
                  # "http://fonds.finanztreff.de/fonds_einzelkurs_uebersicht.htn?u=100&i=%1", 
                  "ISIN:(\\w+)",  # symbolregexp
                  "Tageshoch:.(\\d+,\\d\\d)", # price regexp
                  "Datum.(\d+\D+\d+\D+\d+)", # date regexp
                  "%d.%m.%y" # dateformat
            )

            # WKN als Argument erforderlich.
            self.sources["bo"] = SourceItem("boerseonline",
                  "http://www.boerse-online.de/tools/boerse/einzelkurs_kurse.htm?&s=%1", 
                  "",  # symbolregexp
                  "Akt\. Kurs.(\\d*\.*\\d+,\\d\\d)", # "Ausgabe.([0-9.]+,\\d+)", # priceregexp                  
#                  "Akt\. Kurs.(\\d+,\\d\\d)", # "Ausgabe.([0-9.]+,\\d+)", # priceregexp                  
                  "Datum.(\d+\D+\d+\D+\d+)", # dateregexp
                  "%d.%m.%y" # dateformat
            )

            # WKN als Argument erforderlich. Use this if "bo" does not give any results
            # MZ, 2010-04-19: no longer working
            # self.sources["bo2"] = SourceItem("boerseonline2",
            #       "http://www.boerse-online.de/tools/boerse/fonds_einzelkurs_uebersicht.htm?tranche=%1",
            #       "WKN:\\s(\\w+)",  # symbolregexp
            #       "Datum.(\\d*\.*\\d+,\\d\\d)", 
            #       "(\d+\D+\d+\D+\d+) 1 Jahreschart", # dateregexp
            #       #EUR 16:42 17.07.08 1 Jahreschart
            #       "%d.%m.%y" # dateformat
            # )

      def getSourceNames(self):
            ''' Returns a list of names of the sources available '''
            return self.sources.keys()

      def getSourceItem(self, name):
            ''' Returns a SourceItem instance for source with name = <name> provided
            as arguemtn .'''
            if self.sources.has_key(name):
                  return self.sources[name]
            return None
        



